<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Form Recipients /////////////////////////
// Buttons:
define('FORM_RECIPIENTS_HEADING', "Edit Form saajad");
define('FORM_RECIPIENTS_EDIT_FORM_RECIPIENTS_BTN', "Edit Form saajad");
// Console Text:
define('FORM_RECIPIENTS_FORM_PAGE', "Vorm Page");
define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Sul võib määrata rohkem kui ühele saajale, eraldades kirju komadega.");
// Popup Messages:
define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Salvestamine saaja ...");
define('VIEW_FORM_TABLES_HEADING', "Kuva vormide tabelid");
define('VIEW_FORM_TABLES_BTN', "Kuva vormide tabelid");
define('VIEW_FORM_TABLES_SELECT_TABLE', "Valige tabelid vaatamiseks");
define('VIEW_FORM_TABLES_FILTER_READ', "Filtreeri sõnumite lugemist");
?>